/**************************
	Weather Toolbar
	By Neo101
	Version 1.0.0
**************************/

var SECURITY_ID = dialogArguments.SECURITY_ID
var PLUGIN_NAME = dialogArguments.PLUGIN_NAME

var language = dialogArguments.language
var settings = dialogArguments.settings
var translate = dialogArguments.translate
var translateLocation = dialogArguments.translateLocation
var translateToEnglish = dialogArguments.translateToEnglish

var MaxLib = dialogArguments.MaxLib

var configObj = {}
configObj.units = {'type' : 'select', 'name' : 'units', 'options': {'C' : 'celcius', 'F' : 'fahrenheit'} }
configObj.language = {'type' : 'select', 'name' : 'language', 'options': {'English' : 'English', 'Dutch': 'Dutch', 'Czech': 'Czech'} }


window.onload = function(){
	writeSettingsHtml()
	
	document.title = translate('WeatherButton')
}




function writeSettingsHtml(){
	var html = '<div class="configuration">'
	
    html += '<div class="wrapper">'
	html += '<h2>' + translate('WeatherButton') + ' - ' + translate('configuration') + '</h2>'
	html += '<div>'
	
	var item, option, selected
	for(var setting in configObj){
		item = configObj[setting]
		html += '<div>'
		if(item.type == 'select'){
			html += ' <select id="' + setting + '">'
			for(var option in item.options){
				selected = settings[setting] == option
				html += '  <option value="' + option + '"' + (selected ? ' selected' : '') + '>' + translate(item.options[option]) + '</option>'
			}
			html += ' </select>'
		}
		else if(item.type == 'text'){
			html += ' <input type="text" id="' + setting + '" />'
		}
		html += ' <label>' + translate(item.name) + '</label>'
		html += '</div>'
	}
	
	var translatedLocation = translateLocation( unescape(settings.locationName) )
	
	html += '<div class="locationSearch">'
	html += ' <input type="hidden" id="locationId" value="' + settings.locationId + '" />'
	html += ' <input type="hidden" id="locationName" value="' + settings.locationName + '" />'
	html += ' <br />'
	html += ' <label>' + translate('currentLocation') + ': </label>'
	html += ' <a href="#" onclick="return openCurrentLocation()" onfocus="this.blur()" title="' + translate('openYahooWeather') + '">' + 
				translatedLocation + 
			  '</a>'
	html += ' <br />'
	html += ' <label>' + translate('location') + '</label>'
	html += ' <input type="text" id="locationSearch" onkeydown="checkEnterKey(findLocation)" />'
	html += ' <input type="button" value="' + translate('search') + '" onclick="findLocation()" />'
	html += '</div>'
	html += '<div id="searchResults">'
	html += '</div>'

	html += '</div>'
	
	html += '<div class="configControls">'
	html += ' <input type="button" onclick="saveSettings()" value="' + translate('save') + '" />'
	html += ' <input type="button" onclick="closeWindow(false)" value="' + translate('cancel') + '" />'
	html += '</div>'
	
	html += '</div>'
	html += '</div>'
    
	
	UI.getId('configuration').innerHTML = html
}


function findLocation(){
	var location = UI.getId('locationSearch').value
	
	if(settings.language != 'English'){ // no need to translate for English
		location = translateToEnglish(location)
	}
	
	if(location == ''){
		return
	}
	
	UI.getId('searchResults').innerHTML = translate('loading')
	
	var url = 'http://xml.weather.com/search/search?where=' + location
	
	var callBack = {'onFailure': onResponseFailure, 'onSuccess': onResponseSuccess, 'returnXML':true, 'url':url}
	var number = AjaxLib.openConnection(url, 'GET', callBack, null, true)
	AjaxLib.makeCall( number )
}


function onResponseFailure(connectionObject){
	UI.showError('failure error')
}


function onResponseSuccess(responseXML, object){
	if(responseXML == null){
		UI.showError('null error')
	}
	var cities = parseData(responseXML)
	
	
	var html = '<ul>'
	for(var i=0; i<cities.length; i++){
		html += '<li onclick="setLocationId(\'' + cities[i].id + '\', \'' + escape(cities[i].name) + '\')">' + 
					translateLocation(cities[i].name) + 
				'</li>'
	}
	if(cities.length == 0){
		html += '<li>' + translate('cityNotFound') + '</li>'
	}
	html += '</ul>'
	
	UI.getId('searchResults').innerHTML = html
}


function parseData(xmlObj){
	var result = new Array()
	
	var nodes = xmlObj.selectNodes('search/loc')
	for(var i=0; i<nodes.length; i++){
		result[i] = {'id': getNode(nodes[i], '@id'), 'name':getNode(nodes[i], 'text()')}
	}
	
	return result
}

function getNode(xml, xpath){
	var node = xml.selectSingleNode(xpath)
	return node ? node.text : ''
}


function setLocationId(locationId, locationName){
	UI.getId('locationId').value = locationId
	UI.getId('locationName').value = locationName
	UI.getId('searchResults').innerHTML = translate('locationSet')
}


function saveSettings(){
	var item
	var settingsObjNew = {}
	for(var setting in configObj){
		item = configObj[setting]
		settingsObjNew[setting] = UI.getId(setting).value
	}
	
	settingsObjNew.locationId = UI.getId('locationId').value
	settingsObjNew.locationName = UI.getId('locationName').value
	
	var changedSettings = false
	for(var setting in settings){
		if(settings[setting] != settingsObjNew[setting]){
			changedSettings = true
			break
		}
	}
	
	settings = settingsObjNew
	settings.locationName = unescape(settings.locationName)
	
	if(changedSettings){
		MaxLib.writeFile(dialogArguments.SETTINGS_FILE_NAME, 'settings = ' + JsonLib.objectToJSON(settings))
	}
	
	closeWindow(changedSettings)
}


function closeWindow(changedSettings){
	dialogArguments.configClose(changedSettings)
	window.opener = ''
	window.close()
}

function openCurrentLocation(){
	var url = 'http://weather.yahoo.com/forecast/' + settings.locationId + '_' + settings.units.toLowerCase() + '.html'
	dialogArguments.openUrl(url)
	
	return false
}


function checkEnterKey(functionToRun){
	if (window.event.keyCode == 13){
		functionToRun()
	}
}